@@ -110,6 +110,7 @@ body_add_gg <- function( x, value, width = 6, height = 5, style = NULL, ... ){
 #'
 #' print(doc, target = "body_add_par.docx" )
 #' @importFrom xml2 read_xml xml_find_first write_xml xml_add_sibling as_xml_document
+#' @importFrom htmltools htmlEscape
 body_add_par <- function( x, value, style = NULL, pos = "after" ){
 
   if( is.null(style) )
@@ -119,7 +120,7 @@ body_add_par <- function( x, value, style = NULL, pos = "after" ){
 
   xml_elt <- paste0(wml_with_ns("w:p"),
                     "<w:pPr><w:pStyle w:val=\"", style_id, "\"/></w:pPr><w:r><w:t xml:space=\"preserve\">",
-                    value, "</w:t></w:r></w:p>")
+                    htmlEscape(value), "</w:t></w:r></w:p>")
   body_add_xml(x = x, str = xml_elt, pos = pos)
 }
 
@@ -128,6 +129,7 @@ body_add_par <- function( x, value, style = NULL, pos = "after" ){
 #' @description add an \code{fpar} (a formatted paragraph) into an rdocx object
 #' @param x a docx device
 #' @param value a character
+#' @param style paragraph style
 #' @param pos where to add the new element relative to the cursor,
 #' one of "after", "before", "on".
 #' @examples
@@ -142,12 +144,26 @@ body_add_par <- function( x, value, style = NULL, pos = "after" ){
 #' print(doc, target = "body_add_fpar.docx" )
 #' @importFrom xml2 read_xml xml_find_first write_xml xml_add_sibling as_xml_document
 #' @seealso \code{\link{fpar}}
-body_add_fpar <- function( x, value, pos = "after" ){
+body_add_fpar <- function( x, value, style = NULL, pos = "after" ){
+
+  if( is.null(style) )
+    style <- x$default_styles$paragraph
+  style_id <- x$doc_obj$get_style_id(style=style, type = "paragraph")
 
   xml_elt <- format(value, type = "wml")
   xml_elt <- gsub("<w:p>", wml_with_ns("w:p"), xml_elt )
+  xml_node <- as_xml_document(xml_elt)
+  ppr <- xml_child(xml_node, "w:pPr")
+  xml_remove(xml_children(ppr))
+  xml_add_child(ppr,
+                as_xml_document(
+                  paste0(
+                    "<w:pStyle xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" w:val=\"",
+                    style_id, "\"/>"))
+                )
 
-  body_add_xml(x = x, str = xml_elt, pos = pos)
+
+  body_add_xml(x = x, str = as.character(xml_node), pos = pos)
 }
 
 #' @export
@@ -246,11 +262,12 @@ body_add_xml <- function(x, str, pos){
     stop("unknown pos ", shQuote(pos, type = "sh"), ", it should be ",
          paste( shQuote(pos_list, type = "sh"), collapse = " or ") )
 
+  cursor_elt <- x$doc_obj$get_at_cursor()
+
   if( length(x) == 1 ){
-    xml_add_child(x$doc_obj$get(), xml_elt)
+    xml_add_sibling(cursor_elt, xml_elt, .where = "before")
     x <- cursor_end(x)
   } else {
-    cursor_elt <- x$doc_obj$get_at_cursor()
     if( pos != "on")
       xml_add_sibling(cursor_elt, xml_elt, .where = pos)
     else {
@@ -328,7 +345,14 @@ body_bookmark <- function(x, id){
 #'
 #' print(my_doc, target = "result_doc.docx")
 body_remove <- function(x){
+
   cursor_elt <- x$doc_obj$get_at_cursor()
+
+  if( x$doc_obj$length() == 1 && xml_name(cursor_elt) == "sectPr"){
+    warning("There is nothing left to remove in the document")
+    return(x)
+  }
+
   x$doc_obj$cursor_forward()
   new_cursor_elt <- x$doc_obj$get_at_cursor()
   xml_remove(cursor_elt)
@@ -339,14 +363,15 @@ body_remove <- function(x){
 
 #' @export
 #' @title add section
-#' @description add a section in a Word document. A section is attached to the latest paragraph
-#' of the section.
+#' @description add a section in a Word document. A section has effect
+#' on preceding paragraphs or tables.
 #'
 #' @details
 #' A section start at the end of the previous section (or the beginning of
 #' the document if no preceding section exists), it stops where the section is declared.
-#' The function is reflecting that (complicated) Word concept, by adding an ending section
-#' attached to the paragraph where cursor is.
+#' The function \code{body_end_section()} is reflecting that Word concept.
+#' The function \code{body_default_section()} is only modifying the default section of
+#' the document.
 #' @importFrom xml2 xml_remove
 #' @param x an rdocx object
 #' @param landscape landscape orientation
@@ -354,37 +379,41 @@ body_remove <- function(x){
 #' Sum of this argument should be 1.
 #' @param space space in percent between columns.
 #' @param sep if TRUE a line is sperating columns.
+#' @param continuous TRUE for a continuous section break.
 #' @examples
-#' library(officer)
 #' library(magrittr)
 #'
 #' str1 <- "Lorem ipsum dolor sit amet, consectetur adipiscing elit. " %>%
-#'   rep(20) %>% paste(collapse = "")
-#' str2 <- "Sed hendrerit, est eget convallis vestibulum, mauris ligula. " %>%
-#'   rep(20) %>% paste(collapse = "")
-#' str3 <- "Aenean venenatis varius elit et fermentum vivamus vehicula. " %>%
-#'   rep(20) %>% paste(collapse = "")
+#'   rep(10) %>% paste(collapse = "")
 #'
-#' my_doc <- read_docx()  %>%
-#'   body_add_par("String 1", style = "heading 1") %>%
+#' my_doc <- read_docx() %>%
+#'   # add a paragraph
 #'   body_add_par(value = str1, style = "Normal") %>%
-#'   body_add_par("String 2", style = "heading 1") %>%
-#'   body_add_par(value = str2, style = "Normal") %>%
-#'   body_end_section(landscape = TRUE, colwidths = c(.6, .4), space = .05, sep = FALSE) %>%
-#'   body_add_par("String 3", style = "heading 1") %>%
-#'   body_add_par(value = str3, style = "Normal")
+#'   # add a continuous section
+#'   body_end_section(continuous = TRUE) %>%
+#'   body_add_par(value = str1, style = "Normal") %>%
+#'   body_add_par(value = str1, style = "Normal") %>%
+#'   # preceding paragraph is on a new column
+#'   break_column_before() %>%
+#'   # add a two columns continous section
+#'   body_end_section(colwidths = c(.6, .4),
+#'                    space = .05, sep = FALSE, continuous = TRUE) %>%
+#'   body_add_par(value = str1, style = "Normal") %>%
+#'   # add a continuous section ... so far there is no break page
+#'   body_end_section(continuous = TRUE) %>%
+#'   body_add_par(value = str1, style = "Normal") %>%
+#'   body_default_section(landscape = TRUE)
 #'
-#' print(my_doc, target = "body_end_section.docx")
-#' @importFrom xml2 as_list
-body_end_section <- function(x, landscape = FALSE, colwidths = c(1), space = .05, sep = FALSE){
+#' print(my_doc, target = "section.docx")
+body_end_section <- function(x, landscape = FALSE, colwidths = c(1), space = .05, sep = FALSE, continuous = FALSE){
 
   stopifnot(all.equal( sum(colwidths), 1 ) )
 
+  if( landscape && continuous ){
+    stop("using landscape=TRUE and continuous=TRUE is not possible as changing orientation require a new page.")
+  }
 
-  last_sect <- x$doc_obj$get() %>% xml_find_first("/w:document/w:body/w:sectPr[last()]")
-  section_obj <- as_list(last_sect)
-  sdim <- section_dimensions(last_sect)
-
+  sdim <- x$sect_dim
   h_ref <- sdim$page["height"];w_ref <- sdim$page["width"]
   mar_t <- sdim$margins["top"];mar_b <- sdim$margins["bottom"]
   mar_r <- sdim$margins["right"];mar_l <- sdim$margins["left"]
@@ -419,21 +448,63 @@ body_end_section <- function(x, landscape = FALSE, colwidths = c(1), space = .05
   columns_str_last <- sprintf("<w:col w:w=\"%.0f\"/>",
                               column_values[length(column_values)] * width_)
   columns_str <- c(columns_str_all_but_last, columns_str_last)
-  columns_str <- sprintf("<w:cols w:num=\"%.0f\" w:sep=\"%.0f\" w:space=\"%.0f\" w:equalWidth=\"0\">%s</w:cols>",
+  if( length(colwidths) > 1 )
+    columns_str <- sprintf("<w:cols w:num=\"%.0f\" w:sep=\"%.0f\" w:space=\"%.0f\" w:equalWidth=\"0\">%s</w:cols>",
           length(colwidths), as.integer(sep), space * w, paste0(columns_str, collapse = "") )
+  else columns_str <- sprintf("<w:cols w:space=\"%.0f\" w:equalWidth=\"0\">%s</w:cols>",
+                              space * w, paste0(columns_str, collapse = "") )
 
+  str <- paste0( wml_with_ns("w:p"),
+                 "<w:pPr><w:sectPr>",
+                 ifelse( continuous, "<w:type w:val=\"continuous\"/>", "" ),
+                 pgsz_str, mar_str, columns_str, "</w:sectPr></w:pPr></w:p>")
+  body_add_xml(x, str = str, pos = "after")
+}
+
+#' @export
+#' @rdname body_end_section
+body_default_section <- function(x, landscape = FALSE){
+
+  sdim <- x$sect_dim
+  h_ref <- sdim$page["height"];w_ref <- sdim$page["width"]
+  mar_t <- sdim$margins["top"];mar_b <- sdim$margins["bottom"]
+  mar_r <- sdim$margins["right"];mar_l <- sdim$margins["left"]
+  mar_h <- sdim$margins["header"];mar_f <- sdim$margins["footer"]
+
+  if( !landscape ){
+    h <- h_ref
+    w <- w_ref
+    mar_top <- mar_t
+    mar_bottom <- mar_b
+    mar_right <- mar_r
+    mar_left <- mar_l
+  } else {
+    h <- w_ref
+    w <- h_ref
+    mar_top <- mar_r
+    mar_bottom <- mar_l
+    mar_right <- mar_t
+    mar_left <- mar_b
+  }
+  pgsz_str <- "<w:pgSz %sw:w=\"%.0f\" w:h=\"%.0f\"/>"
+  pgsz_str <- sprintf(pgsz_str, ifelse( landscape, "w:orient=\"landscape\" ", ""), w, h )
+
+  mar_str <- "<w:pgMar w:top=\"%.0f\" w:right=\"%.0f\" w:bottom=\"%.0f\" w:left=\"%.0f\" w:header=\"%.0f\" w:footer=\"%.0f\" w:gutter=\"0\"/>"
+  mar_str <- sprintf(mar_str, mar_top, mar_right, mar_bottom, mar_left, mar_h, mar_f )
 
   str <- paste0( wml_with_ns("w:sectPr"),
-                     pgsz_str, columns_str, mar_str, "</w:sectPr>")
-  xml_elt <- as_xml_document(str)
-
-  cursor_elt <- x$doc_obj$get_at_cursor()
-  if( xml_name(cursor_elt) == "p" )
-    last_pPr <- xml_child(cursor_elt, "w:pPr")
-  else {
-    stop("ending a section can only happen on a paragraph, the cursor is located on a ", xml_name(cursor_elt), ", you may have to add an empty paragraph.")
-  }
-  xml_add_child(.x = last_pPr, .value = xml_elt )
+                 "<w:type w:val=\"continuous\"/>",
+                 pgsz_str, mar_str, "</w:sectPr>")
+  last_sect <- xml_find_first(x$doc_obj$get(), "/w:document/w:body/w:sectPr[last()]")
+  xml_replace(last_sect, as_xml_document(str) )
   x
 }
 
+#' @export
+#' @rdname body_end_section
+break_column_before <- function( x ){
+  xml_elt <- paste0( wml_with_ns("w:r"), "<w:br w:type=\"column\"/>", "</w:r>")
+  slip_in_xml(x = x, str = xml_elt, pos = "before")
+}
+
+
