@@ -15,9 +15,17 @@ pack_folder <- function( folder, target ){
   curr_wd <- getwd()
   zip_dir <- folder
   setwd(zip_dir)
-  zip(zipfile = target,
-      files = list.files(all.files = TRUE, recursive = TRUE))
-  setwd(curr_wd)
+
+  tryCatch(
+    zip(zipfile = target,
+        files = list.files(all.files = TRUE, recursive = TRUE))
+    , error = function(e) {
+      stop("Could not write ", shQuote(target), " [", e$message, "]")
+    }
+    , finally = {
+    setwd(curr_wd)
+  })
+
 
   if( !file.exists(target) ){
     msg <- sprintf("could not zip package %s in file %s", shQuote(zip_dir), shQuote(target))
